==> xsde-1.1.0-i686-linux-gnu.tar.bz2: xsde-1.1.0-i686-linux-gnu/libxsde/xsde/cxx/parser/validating/unsigned-int.cxx <==
// file      : xsde/cxx/parser/validating/unsigned-int.cxx
// author    : Boris Kolpackov <boris@codesynthesis.com>
// copyright : Copyright (c) 2005-2007 Code Synthesis Tools CC
// license   : GNU GPL v2 + exceptions; see accompanying LICENSE file

#include <stdlib.h> // strtoul

#include <xsde/cxx/errno.hxx>

#include <xsde/cxx/parser/validating/unsigned-int.hxx>

namespace xsde
{
  namespace cxx
  {
    namespace parser
    {
      namespace validating
      {
        void unsigned_int_pimpl::
        _pre ()
        {
          size_ = 0;
          sign_ = none;
          state_ = leading_ws;
        }

        void unsigned_int_pimpl::
        _characters (const ro_string& s)
        {
          if (!parse (s, str_, 11))
            schema_error (schema_error::invalid_unsigned_int_value);
        }

        void unsigned_int_pimpl::
        _post ()
        {
          ro_string tmp (str_, size_);
          size_t size = trim_right (tmp);

          if (size != 0 && sign_ != minus && tmp[0] != '-' && tmp[0] != '+')
          {
            str_[size] = '\0';

            char* p;
            set_errno (0);
            unsigned long ul = strtoul (str_, &p, 10);

            if (*p != '\0' || get_errno () != 0 || ul > 4294967295UL)
              schema_error (schema_error::invalid_unsigned_int_value);

            value_ = static_cast<unsigned int> (ul);
          }
          else
            schema_error (schema_error::invalid_unsigned_int_value);
        }

        unsigned int unsigned_int_pimpl::
        post_unsigned_int ()
        {
          return value_;
        }
      }
    }
  }
}

==> xsde-2.1.0-i686-linux-gnu.tar.bz2: xsde-2.1.0-i686-linux-gnu/libxsde/xsde/cxx/parser/validating/unsigned-int.cxx <==
// file      : xsde/cxx/parser/validating/unsigned-int.cxx
// author    : Boris Kolpackov <boris@codesynthesis.com>
// copyright : Copyright (c) 2005-2008 Code Synthesis Tools CC
// license   : GNU GPL v2 + exceptions; see accompanying LICENSE file

#include <stdlib.h> // strtoul

#include <xsde/cxx/errno.hxx>

#include <xsde/cxx/parser/validating/unsigned-int.hxx>

namespace xsde
{
  namespace cxx
  {
    namespace parser
    {
      namespace validating
      {
        void unsigned_int_pimpl::
        _pre ()
        {
          size_ = 0;
          sign_ = none;
          state_ = leading_ws;
        }

        void unsigned_int_pimpl::
        _characters (const ro_string& s)
        {
          if (!parse (s, str_, 11))
            _schema_error (schema_error::invalid_unsigned_int_value);
        }

        void unsigned_int_pimpl::
        _post ()
        {
          ro_string tmp (str_, size_);
          size_t size = trim_right (tmp);

          if (size != 0 && sign_ != minus && tmp[0] != '-' && tmp[0] != '+')
          {
            str_[size] = '\0';

            char* p;
            set_errno (0);
            unsigned long ul = strtoul (str_, &p, 10);

            if (*p != '\0' || get_errno () != 0 || ul > 4294967295UL)
              _schema_error (schema_error::invalid_unsigned_int_value);

            value_ = static_cast<unsigned int> (ul);
          }
          else
            _schema_error (schema_error::invalid_unsigned_int_value);
        }

        unsigned int unsigned_int_pimpl::
        post_unsigned_int ()
        {
          return value_;
        }
      }
    }
  }
}
